==> simg-1.0.0.21.zip: simg-project/application/view/compile/6b514c956b1b471a4e2a795ac3034eee478b70f3.file.welcome.tpl.php <==
<?php /* Smarty version Smarty-3.1.19, created on 2015-04-24 11:32:12
         compiled from "C:\Users\yoshitake\Documents\User\products\simg\develop\simg-project\application\view\template\welcome.tpl" */ ?>
<?php /*%%SmartyHeaderCode:23740547d2f371f0e31-25692344%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    '6b514c956b1b471a4e2a795ac3034eee478b70f3' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\welcome.tpl',
      1 => 1429865777,
      2 => 'file',
    ),
    '0f6400e5bd88edcfc90ce21e2b8330fc68e25b72' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\base.tpl',
      1 => 1429865300,
      2 => 'file',
    ),
  ),
  'nocache_hash' => '23740547d2f371f0e31-25692344',
  'function' => 
  array (
  ),
  'version' => 'Smarty-3.1.19',
  'unifunc' => 'content_547d2f3760bba3_22405024',
  'has_nocache_code' => false,
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_547d2f3760bba3_22405024')) {function content_547d2f3760bba3_22405024($_smarty_tpl) {?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN""http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_CSS'))),$_smarty_tpl);?>
" type="text/css" />
		<script language="javascript" src="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_JS'))),$_smarty_tpl);?>
"></script>
		<title><?php echo $_smarty_tpl->getConfigVariable('PAGE_CAPTION');?>
</title>
		
		
	</head>
	<body>
		<div id="wrapper">
			<div id="header">
				
					<p><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('PAGE_TITLE');?>
</a></p>
				
			</div>
			<div id="commandbar">
				
				
			</div>
			<div id="container">
				

<div id="openarea">

Welcome to the Syscon Sports Magazine !
<p>
<a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_ENTER'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('ENTRY_NAME');?>
</a>
</p>

</div>


			</div>
			<div id="footer">
				
					<p>Copyright 2014- System Concept All rights reserved.</p>
				
			</div>
		</div>
	</body>
</html>
<?php }} ?>

==> simg-1.0.0.23.zip: simg-project/application/view/compile/6b514c956b1b471a4e2a795ac3034eee478b70f3.file.welcome.tpl.php <==
<?php /* Smarty version Smarty-3.1.19, created on 2015-04-28 14:15:24
         compiled from "C:\Users\yoshitake\Documents\User\products\simg\develop\simg-project\application\view\template\welcome.tpl" */ ?>
<?php /*%%SmartyHeaderCode:23740547d2f371f0e31-25692344%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    '6b514c956b1b471a4e2a795ac3034eee478b70f3' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\welcome.tpl',
      1 => 1429865777,
      2 => 'file',
    ),
    '0f6400e5bd88edcfc90ce21e2b8330fc68e25b72' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\base.tpl',
      1 => 1430223271,
      2 => 'file',
    ),
  ),
  'nocache_hash' => '23740547d2f371f0e31-25692344',
  'function' => 
  array (
  ),
  'version' => 'Smarty-3.1.19',
  'unifunc' => 'content_547d2f3760bba3_22405024',
  'has_nocache_code' => false,
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_547d2f3760bba3_22405024')) {function content_547d2f3760bba3_22405024($_smarty_tpl) {?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN""http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" href="<?php echo function_script(array('directory'=>((string)@constant('APP_NAME')),'path'=>'styles.css'),$_smarty_tpl);?>
" type="text/css" />
		<script language="javascript" src="<?php echo function_script(array('directory'=>((string)@constant('APP_NAME')),'path'=>'vote.js'),$_smarty_tpl);?>
"></script>
		<title><?php echo $_smarty_tpl->getConfigVariable('PAGE_CAPTION');?>
</title>
		
		
	</head>
	<body>
		<div id="wrapper">
			<div id="header">
				
					<p><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('PAGE_TITLE');?>
</a></p>
				
			</div>
			<div id="commandbar">
				
				
			</div>
			<div id="container">
				

<div id="openarea">

Welcome to the Syscon Sports Magazine !
<p>
<a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_ENTER'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('ENTRY_NAME');?>
</a>
</p>

</div>


			</div>
			<div id="footer">
				
					<p>Copyright 2014- System Concept All rights reserved.</p>
				
			</div>
		</div>
	</body>
</html>
<?php }} ?>
